Trait SerializeMap

trait SerializeMap

Returned from Serializer::serialize_map.

Example use

# use std::marker::PhantomData;
#
# struct HashMap<K, V>(PhantomData<K>, PhantomData<V>);
#
# impl<K, V> HashMap<K, V> {
#     fn len(&self) -> usize {
#         unimplemented!()
#     }
# }
#
# impl<'a, K, V> IntoIterator for &'a HashMap<K, V> {
#     type Item = (&'a K, &'a V);
#     type IntoIter = Box<dyn Iterator<Item = (&'a K, &'a V)>>;
#
#     fn into_iter(self) -> Self::IntoIter {
#         unimplemented!()
#     }
# }
#
use serde::ser::{Serialize, SerializeMap, Serializer};

impl<K, V> Serialize for HashMap<K, V>
where
    K: Serialize,
    V: Serialize,
{
    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
    where
        S: Serializer,
    {
        let mut map = serializer.serialize_map(Some(self.len()))?;
        for (k, v) in self {
            map.serialize_entry(k, v)?;
        }
        map.end()
    }
}

Example implementation

The example data format presented on the website demonstrates an implementation of SerializeMap for a basic JSON data format.

Associated Types

type Ok

Must match the Ok type of our Serializer.

type Error: TraitBound { trait_: Path { path: "Error", id: Id(220), args: None }, generic_params: [], modifier: None }

Must match the Error type of our Serializer.

Required Methods

fn serialize_key<T>(self: &mut Self, key: &T) -> Result<(), <Self as >::Error>
where
    T: ?Sized + Serialize

Serialize a map key.

If possible, Serialize implementations are encouraged to use serialize_entry instead as it may be implemented more efficiently in some formats compared to a pair of calls to serialize_key and serialize_value.

fn serialize_value<T>(self: &mut Self, value: &T) -> Result<(), <Self as >::Error>
where
    T: ?Sized + Serialize

Serialize a map value.

Panics

Calling serialize_value before serialize_key is incorrect and is allowed to panic or produce bogus results.

fn end(self: Self) -> Result<<Self as >::Ok, <Self as >::Error>

Finish serializing a map.

Provided Methods

fn serialize_entry<K, V>(self: &mut Self, key: &K, value: &V) -> Result<(), <Self as >::Error>
where
    K: ?Sized + Serialize,
    V: ?Sized + Serialize

Serialize a map entry consisting of a key and a value.

Some Serialize types are not able to hold a key and value in memory at the same time so SerializeMap implementations are required to support serialize_key and serialize_value individually. The serialize_entry method allows serializers to optimize for the case where key and value are both available. Serialize implementations are encouraged to use serialize_entry if possible.

The default implementation delegates to serialize_key and serialize_value. This is appropriate for serializers that do not care about performance or are not able to optimize serialize_entry any better than this.

Implementors